%  chap2fig.m                   T.L.Szabo    Version 2 July 2003          
% this program creates figures for waveforms and their spectra for
% Chapter 2 in Diagnostic Ultrasound Imaging: Inside Out
% 
close all;
clear all;
delt0=0.01;           %  time sample increment
nt=256;               % number of time points
t=delt0*(0:nt-1);       %  time array (us)
fc=5.0;               %  center frequency of pulse
a=20.0;                %exponential Gaussian decay factor
fd0=1./(nt*delt0);    %  frequency increment
f1=fd0*[-nt/2:1.0:nt/2-1];         % sets final frequency range
% 
% sets unshifted  frequency range
fun1=zeros(1,nt);
funa=[0.0:nt/2-1];
funb=[-nt/2:-1];
fun1(1:nt/2)=fd0*funa;         
fun1(nt/2+1:nt)=fd0*funb;         % sets unshifted  frequency range
%
%
%A  Fig 2.5
% 5.12 MHz continuous wave tone
fc1=5.12;    %  center frequency is 5.12 MHz
pulse1=sin(2*pi*fc1*t); %  continuous tone waveform
%
% calculate time waveform
figure; subplot(2,1,1);
plot(t,pulse1);
xlabel('Time (us)');ylabel('Amplitude');
Title('5 MHz cw signal');
axis([0.0  2.56 -1.0 1.0]);
%  calculate spectrum
fd0=1./(nt*delt0);     %  frequency increment
f1=fd0*[-nt/2:1.0:(nt/2-1)];         % sets frequency range
%  calculate DFT spectrum magnitude
s1=abs(fftshift(fft(delt0*pulse1)));  %take FFT,mult. by delt0,shuffle
%figure;
subplot(2,1,2);
plot(f1,s1);
%Title('5 MHz cw spectral magnitude');
xlabel('Frequency (MHz)');ylabel('Spectral Magnitude');
axis([-20.  20.0 0.0 2.0]);
% calculate spectral phase
a1=angle(fftshift(fft(delt0*pulse1)));
figure;
plot(f1,a1);
Title('5 MHz cw spectral phase (radians)');
xlabel('Frequency (MHz)');
axis([-20.0  20.0 -4. 4.0]);
%
%AA Fig 2.2
% 5 MHz 10 cycle tone burst
pulse1=cos(2*pi*fc*t); %  cw source waveform
pulse0=zeros(1,nt);
pulse3=pulse0;
pulse3(26:225)=pulse1(26:225);   %  create 10 cycle tone burst
% calculate time waveform
figure;subplot(2,1,1);
plot(t,pulse3);
xlabel('Time (us)');ylabel('Amplitude');
Title('5 MHz 10 cycle tone burst');
axis([0.0  2.5 -1.0 1.0]);
%
% calculate spectral magnitude
s3=abs(fftshift(fft(delt0*pulse3)));
subplot(2,1,2);
plot(f1,s3);
Title('5 MHz 10 cycle tone burst spectral magnitude');
xlabel('Frequency (MHz)');ylabel('Spectral Magnitude');
axis([-20.  20.0 0.0 1.0]);
% calculate spectral phase
a3=angle(fftshift(fft(delt0*pulse3)));
figure;
plot(f1,a3);
Title('5 MHz 10 cycle tone burst spectral phase (radians)');
xlabel('Frequency (MHz)');
%
%BB  Fig 2.3
% 5 MHz 5 cycle tone burst
pulse1=cos(2*pi*fc*t); %  cw source waveform
pulse4=zeros(1,nt);
pulse4=pulse0;
pulse4(76:175)=pulse1(76:175);   %  create 5 cycle tone burst
% calculate time waveform
figure;
subplot(2,1,1);
plot(t,pulse4);
xlabel('Time (us)');ylabel('Amplitude');
Title('5 MHz 5 cycle tone burst');
axis([0.0  2.5 -1.0 1.0]);
%
% calculate spectral magnitude
s4=abs(fftshift(fft(delt0*pulse4)));
subplot(2,1,2);
plot(f1,s4);
%Title('5 MHz 5 cycle tone burst spectral magnitude');
xlabel('Frequency (MHz)');ylabel('Spectral Magnitude');
axis([-20.  20.0 0.0 1.0]);
%
% calculate spectral phase
a4=angle(fftshift(fft(delt0*pulse4)));
figure;
plot(f1,a4);
Title('5 MHz 5 cycle tone burst spectral phase (radians)');
xlabel('Frequency (MHz)');
%
%  Fig 2.1
% 5 MHz Gaussian pulse
tdelay=1.27;
td=tdelay*ones(1,nt);
tt=t-td;
pulse2=exp(-a*tt.*tt).*cos(2*pi*fc*tt);
%
% calculate time waveform
figure;subplot(2,1,1);
plot(t,pulse2);
xlabel('Time (us)');ylabel('Amplitude');
Title('5 MHz Gaussian pulse');
%
% calculate spectral magnitude
s2=abs(fftshift(fft(delt0*pulse2)));
subplot(2,1,2);
plot(f1,s2);
xlabel('Frequency (MHz)');ylabel('Spectral Magnitude');
axis([-10.  10.0 0.0 1.0]);
%
% calculate spectral phase
a2=angle(fftshift(fft(delt0*pulse2)));
figure;
plot(f1,a2);
Title('5 MHz Gaussian pulse spectral phase (radians)');
xlabel('Frequency (MHz)');
%
%  Fig 2.4
% impulse waveform
pulse0=zeros(1,nt);
pulse5=pulse0;
pulse5(127)=10.0;   %  create impulse of amplitude 10
%
% calculate time waveform
figure;subplot(2,1,1);
plot(t,pulse5);
xlabel('Time (us)');ylabel('Amplitude');
Title('impulse');
%
% calculate spectral magnitude
s5=abs(fftshift(fft(delt0*pulse5)));
subplot(2,1,2);

plot(f1,s5);
%Title('impulse spectral magnitude');
xlabel('Frequency (MHz)');ylabel('Spectral Magnitude');
axis([-10.  10.0 0.0 1.0]);
%
% calculate spectral phase
a5=angle(fftshift(fft(delt0*pulse5)));
figure;
plot(f1,a5);
Title('impulse spectral phase (radians)');
xlabel('Frequency (MHz)');
% the end
