%  mtfdemo.m                   T.L.Szabo             July 2004
% this program calculates an  mtf & mirf from chapter 4 of
%  Diagnostic Ultrasound Imaging: Inside Out
% 
close all;clear all;
delt0=0.01;            %  time sample increment
nt=1024;               %  number of time points
t=delt0*(0:nt-1);     %  time array (us)
fd0=1./(nt*delt0);    %  frequency increment
f1=fd0*[-nt/2:1.0:nt/2-1];         % sets final frequency range
%
y=1.5;                  % power exponent
a=50.;
alfa0=0.0;
alfa1=0.1151;         % nepers/MHz/cm = 1 dB/MHz/cm
f0=2.;              %  center frequency in MHz
z=0.135;                 % distance in centimeters
z2=0.675;
z3=1.35;
c0=.15;             % sound speed reference (cm/us) or midband value
del=-2*pi*z/c0;       % handy delay constant
deltaf=del*f1;        % constant sound speed delay term k0z
% sets unshifted  frequency range corresponding to DFT calculation
nulls=zeros(1,nt); 
full=ones(1,nt);
fun1=nulls;
% sets up initial dummy array of zeros
funa=[0.0:nt/2-1];               % positive frequency indices
funb=[-nt/2:-1];                 % negative frequency indices
fun1(1:nt/2)=fd0*funa;           % equates positive frequency segment
fun1(nt/2+1:nt)=fd0*funb;        % equates positive frequency segment
f=fun1;
f00=f0*ones(1,nt);
%
% create Gaussian pulse in time
tdelay=nt*delt0/2.0;                   %  shift to middle of range
td=tdelay*ones(1,nt);                  %  create delay array
tt=t-td;                               %  create shifted time array
pulse3=exp(-a*tt.*tt);                 %  calculate Gaussian time signal
% 
alfa=alfa0*ones(1,nt)+alfa1*(abs(f)).^y;     %   calculate absorption as a function of frequency
beta=nulls;                             % initialize beta arrray
%  calculate betae  according to the value of y 
set=0;
if y==0             % test for y zero
    set=2;
    betae=nulls;
    %beta=2*pi*f/c0;     % betae =0
elseif y==1             % test for y=1
    set=1.;
    betae(1)=0.0;
    betae(2:nt)=-alfa1*(2/pi)*(f(2:nt).^y).*(log(abs(f(2:nt))./(f00(2:nt))));
elseif y==2             % test for y=2
    set=2.;
    betae=nulls;
elseif y==3             % test for y=3
    set=1.;
    betae(1)=0.0;
    betae(2:nt)=-alfa1*(2/pi)*(f(2:nt).^y).*(log(abs(f(2:nt))./(f00(2:nt))));
elseif y>3              % test for y>3
    error('y must be =0 or 3 or be between 0 and 3');
else
    set=0.;
    betae(1)=0.0;
    betae(2:nt)=alfa1*tan(pi*y/2)*f(2:nt).*((abs(f(2:nt)).^(y-1))-(abs(f00(2:nt)).^(y-1)));
end
beta=2*pi*f/c0+betae;
gamma=-alfa-i*beta;
% calculate phase velocity
cinv=ones(1,nt)/c0;
cinv(2:nt)=full(2:nt)/c0+betae(2:nt)./(2*pi*f(2:nt));
c=full./cinv;
delc(1)=0.0;
delc(2:nt)=full(2:nt)./cinv(2:nt)-c0*full(2:nt);  % calculate phase velocity relative to c0
figure;
subplot(2,1,1);
plot(f1,fftshift(alfa));
xlabel('Frequency (MHz)'); Title('Alfa');
subplot(2,1,2);
plot(f1,fftshift(beta));
xlabel('Frequency (MHz)'); Title('Beta');
%
% calculate MTF
mtf=exp(gamma*z);
figure;             % plot MTF
plot(f1,abs(fftshift(mtf)));
xlabel('Frequency  (MHz)'); Title('MTF');
% calculate mirf at three distances
mtf2=exp(gamma*z2);
mtf3=exp(gamma*z3);
mir=ifft(mtf)/delt0;
mir2=ifft(mtf2)/delt0;
mir3=ifft(mtf3)/delt0;
figure; % plot real and imaginary parts of mirf
plot(t,real(mir),'k',t,imag(mir),'r'); 
xlabel('Time (us)'); Title('mirf');
legend('real', 'imaginary')
% Note numerically the imaginary part of mirf is not exactly zero
% but very small so in future just plot the real part of mirf
ainv(85:nt)=1.707*ones(size(t(85:nt)))./(alfa1*c0*t(85:nt)).^(0.67); 
%ainv=1.707*ones(size(t))./(alfa1*c0*t).^(0.67);
%curve 1/a for amplitude asymptote, normalize to mir amp 1
figure;   % plot three mirfs together and show how amplitude falls
subplot(3,1,1);
plot(t,real(mir));
axis([0 10 0 30]);Title('mirf z=0.1 cm');
subplot(3,1,2);
plot(t,real(mir2));
axis([0 10 0 30]);Title('mirf z=1.0 cm');
subplot(3,1,3);
plot(t,real(mir3));
axis([0 10 0 30]);xlabel('Time (us)'); Title('mirf z=10 cm');
figure;
plot(t,real(mir),'k',t,real(mir2),'k',t,real(mir3),'k');
hold on;
xlabel('Time (us)');
%set(get(h, 'Xlabel'), 'FontSize', 18);
ylabel('Amplitude');Title('mirfs for y = 1.5');
axis([0 10 0 30]);
plot(t(85:nt),ainv(85:nt),'r');
% the end